<?php 
namespace CE;

class Anchor{
	
	//Inserta una imagen nueva en base al numero definido por el maquetador
	public static function insert_to_page($pageId, $anchorNumber, $href){
		
		$stmt = \CE\Connection::$conn->prepare(
			"INSERT INTO enlace (num_enlace, href) VALUES(?, ?)"
		);

		//La query es correcta
		if($stmt !== false){
			$stmt->bind_param('is', $anchorNumber, $href);
			$stmt->execute();

			//No ocurrio error al crear el registro en la tabla de texto
			if($stmt !== false){
				$insertedId = $stmt->insert_id;

				//Se inserta a una pagina
				$stmt = \CE\Connection::$conn->prepare(
					"INSERT INTO enlace_por_pagina (id_pagina, id_enlace) VALUES (?, ?)"
				);
				$stmt->bind_param('ii', $pageId, $insertedId);
				$stmt->execute();

				if($stmt !== false){
					$stmt->close();
					return "Elemento creado con éxito";
				}
			}
		}
		//Ocurrio un error
		$stmt->close();
		\CE\Error::report($stmt->error);
		
	}

	public static function insert_to_article($articleId, $anchorNumber, $href){
		
		$stmt = \CE\Connection::$conn->prepare(
			"INSERT INTO enlace (num_enlace, href) VALUES(?, ?)"
		);

		//La query es correcta
		if($stmt !== false){
			$stmt->bind_param('is', $anchorNumber, $href);
			$stmt->execute();

			//No ocurrio error al crear el registro en la tabla de texto
			if($stmt !== false){
				$insertedId = $stmt->insert_id;

				//Se inserta a una pagina
				$stmt = \CE\Connection::$conn->prepare(
					"INSERT INTO enlace_por_articulo (id_articulo, id_enlace) VALUES (?, ?)"
				);
				$stmt->bind_param('ii', $articleId, $insertedId);
				$stmt->execute();

				if($stmt !== false){
					$stmt->close();
					return "Elemento creado con éxito";
				}
			}
		}
		//Ocurrio un error
		$stmt->close();
		\CE\Error::report($stmt->error);
		
	}

	public static function update($anchorId, $href){

		$stmt = \CE\Connection::$conn->prepare(
			"UPDATE enlace SET href = ? WHERE id = ?"
		);
		
		//La query es correcta
		if($stmt !== false){
			$stmt->bind_param('si', $href, $anchorId);
			$stmt->execute();

			//Se actualizo correctamente
			if($stmt !== false){
				$stmt->close();
				return "Actualizado el elemento exitosamente"; //Exito
			}
		}
		$stmt->close();
		\CE\Error::report(\CE\Connection::$stmt->error);
	}

	public static function exists_in_page($pageId, $anchorNumber){
		$stmt = \CE\Connection::$conn->prepare(
			"	SELECT enlace.id FROM enlace JOIN enlace_por_pagina ON
			 	enlace.id = enlace_por_pagina.id_enlace AND enlace_por_pagina.id_pagina=? WHERE enlace.num_enlace = ?
			"
		);

		if($stmt !== false){
			$stmt->bind_param('ii', $pageId, $anchorNumber);
			$stmt->execute();

			$stmt->bind_result($anchorId);
			if ($stmt->fetch()){
			   return true;
			}else{
				return false;
			}
		}
		$stmt->close();
		\CE\Error::report(\CE\Connection::$stmt->error);
	}

	public static function exists_in_article($articleId, $anchorNumber){
		$stmt = \CE\Connection::$conn->prepare(
			"	SELECT enlace.id FROM enlace JOIN enlace_por_articulo ON
			 	enlace.id = enlace_por_articulo.id_enlace AND enlace_por_articulo.id_articulo=? WHERE enlace.num_enlace = ?
			"
		);

		if($stmt !== false){
			$stmt->bind_param('ii', $articleId, $anchorNumber);
			$stmt->execute();

			$stmt->bind_result($anchorId);
			if ($stmt->fetch()){
			   return true;
			}else{
				return false;
			}
		}
		$stmt->close();
		\CE\Error::report(\CE\Connection::$stmt->error);
	}

	//Obtiene el id de un texto, en base al id de la pagina y el numero definido por el maquetador
	public static function getID_in_page($pageId, $anchorNumber){
		$stmt = \CE\Connection::$conn->prepare(
			"	SELECT enlace.id FROM enlace JOIN enlace_por_pagina ON 
			 	enlace.id = enlace_por_pagina.id_enlace AND enlace_por_pagina.id_pagina=? WHERE enlace.num_enlace = ?
			"
		);

		if($stmt !== false){
			$stmt->bind_param('ii', $pageId, $anchorNumber);
			$stmt->execute();

			$stmt->bind_result($anchorId);
			$stmt->fetch();
			return $anchorId;
		}
		$stmt->close();
		\CE\Error::report(\CE\Connection::$conn->error);
	}

	public static function getID_in_article($articleId, $anchorNumber){
		$stmt = \CE\Connection::$conn->prepare(
			"	SELECT enlace.id FROM enlace JOIN enlace_por_articulo ON 
			 	enlace.id = enlace_por_articulo.id_enlace AND enlace_por_articulo.id_articulo=? WHERE enlace.num_enlace = ?
			"
		);

		if($stmt !== false){
			$stmt->bind_param('ii', $articleId, $anchorNumber);
			$stmt->execute();

			$stmt->bind_result($anchorId);
			$stmt->fetch();
			return $anchorId;
		}
		$stmt->close();
		\CE\Error::report(\CE\Connection::$conn->error);
	}

	
}
?>