<?php 
namespace CE;

class Article{
	
	//Inserta un texto nuevo en base al numero definido por el maquetador
	public static function insert_to_category($categoryId, $articleNumber){
		
		$stmt = \CE\Connection::$conn->prepare(
			"INSERT INTO articulo (num_articulo) VALUES(?)"
		);

		//La query es correcta
		if($stmt !== false){
			$stmt->bind_param('i', $articleNumber);
			$stmt->execute();

			//No ocurrio error al crear el registro en la tabla de articulo
			if($stmt !== false){
				$insertedId = $stmt->insert_id;
				
				//Se inserta a una categoria
				
				$stmt = \CE\Connection::$conn->prepare(
					"INSERT INTO articulos_por_categoria (id_categoria, id_articulo) VALUES (?, ?)"
				);
				$stmt->bind_param('ii', $categoryId, $insertedId);

				$stmt->execute();

				if($stmt !== false){
					$stmt->close();
					return $insertedId;
				}
			}
		}
		//Ocurrio un error
		$stmt->close();
		\CE\Error::report($stmt->error);
		
	}

	public static function exists_in_category($categoryId, $articleNumber){
		$stmt = \CE\Connection::$conn->prepare(
			"	SELECT articulo.id FROM articulo JOIN articulos_por_categoria ON
			 	articulo.id = articulos_por_categoria.id_articulo AND articulos_por_categoria.id_categoria=? WHERE articulo.num_articulo = ?
			"
		);

		if($stmt !== false){
			$stmt->bind_param('ii', $categoryId, $articleNumber);
			$stmt->execute();

			$stmt->bind_result($textId);
			if ($stmt->fetch()){
			   return true;
			}else{
				return false;
			}
		}
		$stmt->close();
		\CE\Error::report(\CE\Connection::$stmt->error);
	}

	public static function remove($articleId){
		$stmt = \CE\Connection::$conn->prepare(
			"UPDATE articulo SET estaEliminado = 1 WHERE id = ?"
		);
		
		//La query es correcta
		if($stmt !== false){
			$stmt->bind_param('i', $articleId);
			$stmt->execute();

			//Se actualizo correctamente
			if($stmt !== false){
				$stmt->close();
				return "Eliminado el elemento exitosamente"; //Exito
			}
		}
		$stmt->close();
		\CE\Error::report(\CE\Connection::$stmt->error);
	}

	//Obtiene el id de un texto, en base al id de la pagina y el numero definido por el maquetador
	public static function getId($categoryId, $articleNumber){
		$stmt = \CE\Connection::$conn->prepare(
			"	SELECT articulo.id FROM articulo JOIN articulos_por_categoria ON
			 	articulo.id = articulos_por_categoria.id_articulo AND articulos_por_categoria.id_categoria=? WHERE articulo.num_articulo = ?
			"
		);

		if($stmt !== false){
			$stmt->bind_param('ii', $categoryId, $articleNumber);
			$stmt->execute();

			$stmt->bind_result($articleId);
			$stmt->fetch();
			return $articleId;
		}
		$stmt->close();
		\CE\Error::report(\CE\Connection::$conn->error);
	}

	//Obtiene el ultimo numero de articulo registrado (no el id)
	public static function getNextNumber($categoryId){
		$stmt = \CE\Connection::$conn->prepare(
			"	SELECT articulo.num_articulo FROM articulo JOIN articulos_por_categoria ON
			 	articulo.id = articulos_por_categoria.id_articulo AND articulos_por_categoria.id_categoria=? AND articulo.esPublico = 1 ORDER BY articulo.num_articulo DESC
			"
		);

		if($stmt !== false){
			$stmt->bind_param('i', $categoryId);
			$stmt->execute();

			$stmt->bind_result($lastNumber);
			if ($stmt->fetch()){
			   return ($lastNumber + 1);
			}else{
				return 1; //No hay articulos en la categoria, empezar con el primero
			}
		}
		$stmt->close();
		\CE\Error::report(\CE\Connection::$conn->error);
	}

}
?>