<?php 
namespace CE;

class Image{
	
	//Inserta una imagen nueva en base al numero definido por el maquetador
	public static function insert_to_page($pageId, $imageNumber, $src){
		
		$stmt = \CE\Connection::$conn->prepare(
			"INSERT INTO imagen (num_imagen, src) VALUES(?, ?)"
		);

		//La query es correcta
		if($stmt !== false){
			$stmt->bind_param('is', $imageNumber, $src);
			$stmt->execute();

			//No ocurrio error al crear el registro en la tabla de texto
			if($stmt !== false){
				$insertedId = $stmt->insert_id;

				//Se inserta a una pagina
				$stmt = \CE\Connection::$conn->prepare(
					"INSERT INTO imagen_por_pagina (id_pagina, id_imagen) VALUES (?, ?)"
				);
				$stmt->bind_param('ii', $pageId, $insertedId);
				$stmt->execute();

				if($stmt !== false){
					$stmt->close();
					return "Elemento creado con éxito";
				}
			}
		}
		//Ocurrio un error
		$stmt->close();
		\CE\Error::report($stmt->error);
		
	}

	public static function insert_to_article($articleId, $imageNumber, $src){
		
		$stmt = \CE\Connection::$conn->prepare(
			"INSERT INTO imagen (num_imagen, src) VALUES(?, ?)"
		);

		//La query es correcta
		if($stmt !== false){
			$stmt->bind_param('is', $imageNumber, $src);
			$stmt->execute();

			//No ocurrio error al crear el registro en la tabla de texto
			if($stmt !== false){
				$insertedId = $stmt->insert_id;

				//Se inserta a una pagina
				$stmt = \CE\Connection::$conn->prepare(
					"INSERT INTO imagen_por_articulo (id_articulo, id_imagen) VALUES (?, ?)"
				);
				$stmt->bind_param('ii', $articleId, $insertedId);
				$stmt->execute();

				if($stmt !== false){
					$stmt->close();
					return "Elemento creado con éxito";
				}
			}
		}
		//Ocurrio un error
		$stmt->close();
		\CE\Error::report($stmt->error);
		
	}

	public static function update($imageId, $src){

		$stmt = \CE\Connection::$conn->prepare(
			"UPDATE imagen SET src = ? WHERE id = ?"
		);
		
		//La query es correcta
		if($stmt !== false){
			$stmt->bind_param('si', $src, $imageId);
			$stmt->execute();

			//Se actualizo correctamente
			if($stmt !== false){
				$stmt->close();
				return "Actualizado el elemento exitosamente"; //Exito
			}
		}
		$stmt->close();
		\CE\Error::report(\CE\Connection::$stmt->error);
	}

	public static function updateAlt($imageId, $alt){

		$stmt = \CE\Connection::$conn->prepare(
			"UPDATE imagen SET alt = ? WHERE id = ?"
		);
		
		//La query es correcta
		if($stmt !== false){
			$stmt->bind_param('si', $alt, $imageId);
			$stmt->execute();

			//Se actualizo correctamente
			if($stmt !== false){
				$stmt->close();
				return "Actualizado el elemento exitosamente"; //Exito
			}
		}
		$stmt->close();
		\CE\Error::report(\CE\Connection::$stmt->error);
	}

	public static function exists_in_page($pageId, $imageNumber){
		$stmt = \CE\Connection::$conn->prepare(
			"	SELECT imagen.id FROM imagen JOIN imagen_por_pagina ON
			 	imagen.id = imagen_por_pagina.id_imagen AND imagen_por_pagina.id_pagina=? WHERE imagen.num_imagen = ?
			"
		);

		if($stmt !== false){
			$stmt->bind_param('ii', $pageId, $imageNumber);
			$stmt->execute();

			$stmt->bind_result($imageId);
			if ($stmt->fetch()){
			   return true;
			}else{
				return false;
			}
		}
		$stmt->close();
		\CE\Error::report(\CE\Connection::$stmt->error);
	}

	public static function exists_in_article($articleId, $imageNumber){
		$stmt = \CE\Connection::$conn->prepare(
			"	SELECT imagen.id FROM imagen JOIN imagen_por_articulo ON
			 	imagen.id = imagen_por_articulo.id_imagen AND imagen_por_articulo.id_articulo=? WHERE imagen.num_imagen = ?
			"
		);

		if($stmt !== false){
			$stmt->bind_param('ii', $articleId, $imageNumber);
			$stmt->execute();

			$stmt->bind_result($imageId);
			if ($stmt->fetch()){
			   return true;
			}else{
				return false;
			}
		}
		$stmt->close();
		\CE\Error::report(\CE\Connection::$stmt->error);
	}

	//Obtiene el id de un texto, en base al id de la pagina y el numero definido por el maquetador
	public static function getID_in_page($pageId, $imageNumber){
		$stmt = \CE\Connection::$conn->prepare(
			"	SELECT imagen.id FROM imagen JOIN imagen_por_pagina ON 
			 	imagen.id = imagen_por_pagina.id_imagen AND imagen_por_pagina.id_pagina=? WHERE imagen.num_imagen = ?
			"
		);

		if($stmt !== false){
			$stmt->bind_param('ii', $pageId, $imageNumber);
			$stmt->execute();

			$stmt->bind_result($imageId);
			$stmt->fetch();
			return $imageId;
		}
		$stmt->close();
		\CE\Error::report(\CE\Connection::$conn->error);
	}

	public static function getID_in_article($articleId, $imageNumber){
		$stmt = \CE\Connection::$conn->prepare(
			"	SELECT imagen.id FROM imagen JOIN imagen_por_articulo ON 
			 	imagen.id = imagen_por_articulo.id_imagen AND imagen_por_articulo.id_articulo=? WHERE imagen.num_imagen = ?
			"
		);

		if($stmt !== false){
			$stmt->bind_param('ii', $articleId, $imageNumber);
			$stmt->execute();

			$stmt->bind_result($imageId);
			$stmt->fetch();
			return $imageId;
		}
		$stmt->close();
		\CE\Error::report(\CE\Connection::$conn->error);
	}
}
?>