<?php 
namespace CE;

class Text{
	
	//Inserta un texto nuevo en base al numero definido por el maquetador
	public static function insert_to_page($pageId, $textNumber, $content){
		
		$stmt = \CE\Connection::$conn->prepare(
			"INSERT INTO texto (num_texto, contenido) VALUES(?, ?)"
		);

		//La query es correcta
		if($stmt !== false){
			$stmt->bind_param('is', $textNumber, $content);
			$stmt->execute();

			//No ocurrio error al crear el registro en la tabla de texto
			if($stmt !== false){
				$insertedId = $stmt->insert_id;
				
				//Se inserta a una pagina
				$stmt = \CE\Connection::$conn->prepare(
					"INSERT INTO texto_por_pagina (id_pagina, id_texto) VALUES (?, ?)"
				);
				$stmt->bind_param('ii', $pageId, $insertedId);

				$stmt->execute();

				if($stmt !== false){
					$stmt->close();
					return "Elemento creado con éxito";
				}
			}
		}
		//Ocurrio un error
		$stmt->close();
		\CE\Error::report($stmt->error);
		
	}

	public static function insert_to_article($articleId, $textNumber, $content){
		
		$stmt = \CE\Connection::$conn->prepare(
			"INSERT INTO texto (num_texto, contenido) VALUES(?, ?)"
		);

		//La query es correcta
		if($stmt !== false){
			$stmt->bind_param('is', $textNumber, $content);
			$stmt->execute();

			//No ocurrio error al crear el registro en la tabla de texto
			if($stmt !== false){
				$insertedId = $stmt->insert_id;
				
				//Se inserta a una pagina
				$stmt = \CE\Connection::$conn->prepare(
					"INSERT INTO texto_por_articulo (id_articulo, id_texto) VALUES (?, ?)"
				);
				$stmt->bind_param('ii', $articleId, $insertedId);

				$stmt->execute();

				if($stmt !== false){
					$stmt->close();
					return "Elemento creado con éxito";
				}
			}
		}
		//Ocurrio un error
		$stmt->close();
		\CE\Error::report($stmt->error);
		
	}

	public static function update($textId, $content){

		$stmt = \CE\Connection::$conn->prepare(
			"UPDATE texto SET contenido = ? WHERE id = ?"
		);
		
		//La query es correcta
		if($stmt !== false){
			$stmt->bind_param('si', $content, $textId);
			$stmt->execute();

			//Se actualizo correctamente
			if($stmt !== false){
				$stmt->close();
				return "Actualizado el elemento exitosamente"; //Exito
			}
		}
		$stmt->close();
		\CE\Error::report(\CE\Connection::$stmt->error);
	}

	public static function exists_in_page($pageId, $textNumber){
		$stmt = \CE\Connection::$conn->prepare(
			"	SELECT texto.id FROM texto JOIN texto_por_pagina ON
			 	texto.id = texto_por_pagina.id_texto AND texto_por_pagina.id_pagina=? WHERE texto.num_texto = ?
			"
		);

		if($stmt !== false){
			$stmt->bind_param('ii', $pageId, $textNumber);
			$stmt->execute();

			$stmt->bind_result($textId);
			if ($stmt->fetch()){
			   return true;
			}else{
				return false;
			}
		}
		$stmt->close();
		\CE\Error::report(\CE\Connection::$stmt->error);
	}

	public static function exists_in_article($articleId, $textNumber){
		$stmt = \CE\Connection::$conn->prepare(
			"	SELECT texto.id FROM texto JOIN texto_por_articulo ON
			 	texto.id = texto_por_articulo.id_texto AND texto_por_articulo.id_articulo=? WHERE texto.num_texto = ?
			"
		);

		if($stmt !== false){
			$stmt->bind_param('ii', $articleId, $textNumber);
			$stmt->execute();

			$stmt->bind_result($textId);
			if ($stmt->fetch()){
			   return true;
			}else{
				return false;
			}
		}
		$stmt->close();
		\CE\Error::report(\CE\Connection::$stmt->error);
	}

	//Obtiene el id de un texto, en base al id de la pagina y el numero definido por el maquetador
	public static function getID_in_page($pageId, $textNumber){
		$stmt = \CE\Connection::$conn->prepare(
			"	SELECT texto.id FROM texto JOIN texto_por_pagina ON
			 	texto.id = texto_por_pagina.id_texto AND texto_por_pagina.id_pagina=? WHERE texto.num_texto = ?
			"
		);

		if($stmt !== false){
			$stmt->bind_param('ii', $pageId, $textNumber);
			$stmt->execute();

			$stmt->bind_result($textId);
			$stmt->fetch();
			return $textId;
		}
		$stmt->close();
		\CE\Error::report(\CE\Connection::$conn->error);
	}

	public static function getID_in_article($articleId, $textNumber){
		$stmt = \CE\Connection::$conn->prepare(
			"	SELECT texto.id FROM texto JOIN texto_por_articulo ON
			 	texto.id = texto_por_articulo.id_texto AND texto_por_articulo.id_articulo=? WHERE texto.num_texto = ?
			"
		);

		if($stmt !== false){
			$stmt->bind_param('ii', $articleId, $textNumber);
			$stmt->execute();

			$stmt->bind_result($textId);
			$stmt->fetch();
			return $textId;
		}
		$stmt->close();
		\CE\Error::report(\CE\Connection::$conn->error);
	}


}
?>